@@ -44,6 +44,7 @@ __all__ = (
     "BackendAPIAuthTypeTypeDef",
     "BackendAPIConflictResolutionTypeDef",
     "BackendAPIResourceConfigTypeDef",
+    "BackendAuthAppleProviderConfigTypeDef",
     "BackendAuthSocialProviderConfigTypeDef",
     "BackendJobRespObjTypeDef",
     "CloneBackendRequestRequestTypeDef",
@@ -164,6 +165,17 @@ BackendAPIResourceConfigTypeDef = TypedDict(
     total=False,
 )
 
+BackendAuthAppleProviderConfigTypeDef = TypedDict(
+    "BackendAuthAppleProviderConfigTypeDef",
+    {
+        "ClientId": str,
+        "KeyId": str,
+        "PrivateKey": str,
+        "TeamId": str,
+    },
+    total=False,
+)
+
 BackendAuthSocialProviderConfigTypeDef = TypedDict(
     "BackendAuthSocialProviderConfigTypeDef",
     {
@@ -957,6 +969,7 @@ SocialProviderSettingsTypeDef = TypedDict(
         "Facebook": "BackendAuthSocialProviderConfigTypeDef",
         "Google": "BackendAuthSocialProviderConfigTypeDef",
         "LoginWithAmazon": "BackendAuthSocialProviderConfigTypeDef",
+        "SignInWithApple": "BackendAuthAppleProviderConfigTypeDef",
     },
     total=False,
 )
